@@ -60,9 +60,6 @@ static const char alphanum[] =
 	"abcdefghijklmnopqrstuvwxyz";
 static char random_string[RANDOM_STRING_LEN];
 
-static struct ltt_ust_session *usess;
-static struct lttng_domain dom;
-
 /*
  * Return random string of 10 characters.
  * Not thread-safe.
@@ -82,9 +79,9 @@ static char *get_random_string(void)
 
 static void test_create_one_ust_session(void)
 {
-	dom.type = LTTNG_DOMAIN_UST;
+	struct ltt_ust_session *usess =
+		trace_ust_create_session(42);
 
-	usess = trace_ust_create_session(42);
 	ok(usess != NULL, "Create UST session");
 
 	if (!usess) {
@@ -117,8 +114,8 @@ static void test_create_ust_channel(void)
 	uchan = trace_ust_create_channel(&attr, LTTNG_DOMAIN_UST);
 	ok(uchan != NULL, "Create UST channel");
 
-	if (!usess) {
-		skip(1, "UST session is null");
+	if (!uchan) {
+		skip(1, "UST channel is null");
 		return;
 	}
 
@@ -252,8 +249,12 @@ static void test_create_ust_context(void)
 	uctx = trace_ust_create_context(&ectx);
 	ok(uctx != NULL, "Create UST context");
 
-	ok((int) uctx->ctx.ctx == LTTNG_UST_CONTEXT_VTID,
-	   "Validate UST context");
+	if (uctx) {
+		ok((int) uctx->ctx.ctx == LTTNG_UST_CONTEXT_VTID,
+		   "Validate UST context");
+	} else {
+		skip(1, "Skipping UST context validation as creation failed");
+	}
 	free(uctx);
 }
 
